
# Slot: node_path


The path to the file with the unique node names.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_path](https://w3id.org/neat/ensmallenRunConfig__node_path)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
